@@ -6,12 +6,16 @@ class AsyncBaseAdapter(ABC):
     async def _get_user(self, login):
         pass
 
+    @abstractmethod
+    async def get_user_zero_depth_rules(self, login):
+        pass
+
     @abstractmethod
     async def get_user_zero_depth_roles(self, login):
         pass
 
     @abstractmethod
-    async def get_extended_role(self, role):
+    async def get_extended_rules(self, role):
         pass
 
     @abstractmethod
@@ -24,12 +28,16 @@ class BaseAdapter(ABC):
     def _get_user(self, login):
         pass
 
+    @abstractmethod
+    def get_user_zero_depth_rules(self, login):
+        pass
+
     @abstractmethod
     def get_user_zero_depth_roles(self, login):
         pass
 
     @abstractmethod
-    def get_extended_role(self, role):
+    def get_extended_rules(self, role):
         pass
 
     @abstractmethod
